LLMDB.DeepMergeShim (LLM DB v2026.3.0)

Copy Markdown View Source

Shim to call DeepMerge.deep_merge/3 with a 3-arity resolver without Dialyzer false positives.

DeepMerge's typespec advertises a 2-arity resolver (any(), any() -> any()) but the actual runtime implementation calls the resolver with 3 arguments (key, left, right).

This shim hides the call from Dialyzer while providing the correct typespec for our usage.

Summary

Types

resolver3()

@type resolver3() :: (any(), any(), any() -> any())

Functions

deep_merge(left, right, resolver3)

@spec deep_merge(any(), any(), resolver3()) :: any()