LLMDB.LoadError exception (LLM DB v2026.7.3)

Copy Markdown View Source

Raised when lazy catalog initialization fails on the first public query.

Call LLMDB.load/1 explicitly when the caller needs to handle the same failure as an {:error, reason} tuple.