Auto-generated module containing all valid modality atoms.
This module is generated to prevent atom leaking by ensuring all modality atoms exist at compile time before String.to_existing_atom/1 is used.
DO NOT EDIT THIS FILE MANUALLY - it will be overwritten.
Summary
Functions
Returns the list of all valid modality atoms.
Checks if the given atom is a valid modality.