Raised when lazy catalog initialization fails on the first public query.
Call LLMDB.load/1 explicitly when the caller needs to handle the same
failure as an {:error, reason} tuple.
Raised when lazy catalog initialization fails on the first public query.
Call LLMDB.load/1 explicitly when the caller needs to handle the same
failure as an {:error, reason} tuple.