Builds a canonical snapshot.json from configured sources.
The snapshot is always written to a local build output directory. Use
--install to also copy it into priv/llm_db/snapshot.json for local runtime
loading or packaging.
Usage
mix llm_db.build
mix llm_db.build --install
mix llm_db.build --check
mix llm_db.build --output-dir tmp/llm_db/buildOptions
--check- Verify the generated snapshot artifacts already match the expected output.--install- Also install the built snapshot intopriv/llm_db/snapshot.json.--output-dir- Directory for local snapshot build artifacts.